@@ -1,5 +1,5 @@
 import yapenv.commands as yapenv_commands
-from yapenv.format import PrintFormat
+from bole.format import PrintFormat
 from yapenv.cli.options import CommonOptions, FormatOptions
 from yapenv.cli.core import yapenv
 
